
#include <termios.h>
#include <unistd.h>
#include <fcntl.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <sys/ioctl.h>

#define READ 0
#define WRITE 1
#define READ_WRITE 2
#define NO_HANDSHAKE 0
#define HW_HANDSHAKE 1


/*
  COM_open apre una porta seriale impostandone i parametri di comunicazione:

  port:		numero di porta seriale (0, 1, 2, ..., 9)
  mode: 	READ (0), WRITE (1) o READ_WRITE (2)
  speed: 	4800, 9600, 19200, 38400 0 57600
  parity:	N/n (NONE), E/e (EVEN), O/o (ODD)
  bits:		7 o 8
  stop: 	1 o 2
  flow: 	NO_HANDSHAKE (0) o HW_HANDSHAKE (1)
  
  Restituisce:	un identificatore da utilizzare nelle funzioni di trasmissione/ricezione
  							un valore negativo in caso di errore
*/
int COM_open (unsigned char port, unsigned char mode, unsigned short speed, char parity, unsigned char bits, unsigned char stop, unsigned char flow);

/*
  Trasmissione di un buffer di N caratteri sulla linea seriale
  
  com:		identificatore restituito da COM_open
  buffer:	buffer dei caratteri da trasmettere
  N:			numero dei caratteri da trasmettere presenti nel buffer
  
  Restituisce:	il numero dei caratteri effettivamente trasmessi
  							un valore negativo in caso di errore
*/
int COM_write (int com, char buffer[], int N);

/*
  Ricezione in un buffer di caratteri dalla linea seriale
  
  com:		identificatore restituito da COM_open
  buffer:	buffer per la memorizzazione dei caratteri ricevuti
  N:			numero massimo dei caratteri ricevibili nel buffer
  
  Restituisce:	il numero dei caratteri ricevuti (0 = nessuno)
  							un valore negativo in caso di errore
*/
int COM_read (int com, char *buffer, int N);

/*
  Chiude una porta seriale
  
  com:		identificatore restituito da COM_open
*/
void COM_close(int com);
